@@ -1,7 +1,7 @@
 package Proc::Govern;
 
-our $DATE = '2019-05-22'; # DATE
-our $VERSION = '0.205'; # VERSION
+our $DATE = '2019-05-23'; # DATE
+our $VERSION = '0.206'; # VERSION
 
 use 5.010001;
 use strict;
@@ -100,6 +100,10 @@ Passed to <pm:IPC::Run>'s `start()`.
 
 _
         },
+        nice => {
+            summary => 'Set nice/priority level',
+            schema => ['int*'],
+        },
         single_instance => {
             schema => [bool => default => 0],
             description => <<'_',
@@ -464,12 +468,20 @@ sub govern_process {
             -euid => $args{euid},
             -egid => $args{egid},
         ) if defined $args{euid} || defined $args{egid};
+
         log_debug "[govproc] (Re)starting program $name ...";
         $to = IPC::Run::timeout(1);
         #$self->{to} = $to;
         $h  = IPC::Run::start($cmd, \*STDIN, $out, $err, $to)
             or die "Can't start program: $?";
         $self->{h} = $h;
+
+        if (defined $args{nice}) {
+            log_debug "[govproc] Setting nice level of PID %d to %d ...",
+                $h->{KIDS}[0]{PID}, $args{nice};
+            setpriority(0, $h->{KIDS}[0]{PID}, $args{nice});
+        }
+
         IPC::Run::Patch::Setuid->unimport()
               if defined $args{euid} || defined $args{egid};
     };
@@ -625,7 +637,7 @@ Proc::Govern - Run child process and govern its various aspects
 
 =head1 VERSION
 
-This document describes version 0.205 of Proc::Govern (from Perl distribution Proc-Govern), released on 2019-05-22.
+This document describes version 0.206 of Proc::Govern (from Perl distribution Proc-Govern), released on 2019-05-23.
 
 =head1 SYNOPSIS
 
@@ -721,12 +733,18 @@ Currently the following governing functionalities are available:
 
 =item * execution time limit
 
+=item * set (CPU) nice level (priority)
+
 =item * preventing multiple instances from running simultaneously
 
 =item * load watch
 
 =item * autorestart
 
+=item * preventing system from sleeping while process is running
+
+=item * preventing screensaver from activating while process is running
+
 =back
 
 In the future the following features are also planned or contemplated:
@@ -743,8 +761,6 @@ With an option to autorestart if process' memory size grow out of limit.
 
 =item * fork/start multiple processes
 
-=item * set (CPU) nice level
-
 =item * set I/O nice level (scheduling priority/class)
 
 =item * limit STDIN input, STDOUT/STDERR output?
@@ -880,6 +896,10 @@ L<File::Write::Rotate>'s constructor as well as used as name of PID file.
 
 If not given, will be taken from command.
 
+=item * B<nice> => I<int>
+
+Set nice/priority level.
+
 =item * B<no_screensaver> => I<true>
 
 Prevent screensaver from being activated.
